==> foundation-utils-2.0.7.tgz: package/src/number/scientificNotation.ts <==
/**
 * 科学计数转换
 * @param num_str 
 * @returns 
 */
function NumberScientificNotation(num_str: string): string {
  num_str = num_str.toString();
  if (num_str.indexOf("+") != -1) {
    num_str = num_str.replace("+", "");
  }
  if (num_str.indexOf("E") == -1 && num_str.indexOf("e") == -1) {
    return num_str;
  }

  let resValue = "", power = "", sym = "";
  let numStr = num_str.toString();
  if (numStr[0] == "-") {
    // 如果为负数，转成正数处理，先去掉‘-’号，并保存‘-’.
    numStr = numStr.substr(1);
    sym = "-";
  }

  let regExp = new RegExp("^(((\\d+.?\\d+)|(\\d+))[Ee]{1}((-(\\d+))|(\\d+)))$", "ig");
  let result = regExp.exec(numStr);
  if (result != null) {
    resValue = result[2];
    power = result[5];
    result = null;
  }
  if (!resValue && !power) {
    return num_str;
  }
  let dotIndex = resValue.indexOf(".") == -1 ? 0 : resValue.indexOf(".");
  let resArr = resValue.split("");
  resValue = resValue.replace(".", "");
  let powerNum = Number(power);
  if (powerNum >= 0) {
    // 正次幂
    positivePower(powerNum, resValue, dotIndex, resArr);
  } else {
    // 负次幂
    let powerNum = Number(power.replace("-", ""));
    negativePower(powerNum, resValue, dotIndex, resArr);
  }
  resValue = resArr.join("");
  return sym + resValue;
}

// 正次幂
function positivePower(powerNum: number, resValue: string, dotIndex: number, resArr: any) {
  // 有小数
  if (dotIndex > 0) {
    let substr = resValue.substr(dotIndex);
    //幂数大于小数点后面的数字位数时，后面加0
    for (let i = 0; i < powerNum - substr.length; i++) {
      resArr.push("0");
    }
    if (powerNum - substr.length < 0) {
      resArr.splice(dotIndex + powerNum + 1, 0, ".");
    }

    if (dotIndex > 0) {
      resArr.splice(dotIndex, 1);
    }
  } else {
    for (let i = 0; i < powerNum; i++) {
      resArr.push("0");
    }
  }
}
// 负次幂
function negativePower(powerNum: number, resValue: string, dotIndex: number, resArr: any) {
  // 有小数
  if (dotIndex > 0) {
    resArr.splice(dotIndex, 1);
    //幂数大于等于 小数点的index位置, 前面加0
    for (let i = 0; i <= powerNum - dotIndex; i++) {
      resArr.unshift("0");
    }
    let n = powerNum - dotIndex >= 0 ? 1 : -(powerNum - dotIndex);
    resArr.splice(n, 0, ".");
  } else {
    for (let i = 0; i <= powerNum - resValue.length; i++) {
      resArr.unshift("0");
    }
    let n = powerNum - resValue.length >= 0 ? 1 : -(powerNum - resValue.length);
    resArr.splice(n, 0, ".");
  }
}

export {
  NumberScientificNotation
}

==> foundation-utils-2.0.18.tgz: package/src/number/scientificNotation.ts <==
/**
 * 科学计数转换
 * @param value 
 * @returns 
 */
function NumberScientificNotation(value: string): string {
  value = value.toString();
  if (value.indexOf("+") != -1) {
    value = value.replace("+", "");
  }
  if (value.indexOf("E") == -1 && value.indexOf("e") == -1) {
    return value;
  }

  let resValue = "", power = "", sym = "";
  let numStr = value.toString();
  if (numStr[0] == "-") {
    // 如果为负数，转成正数处理，先去掉‘-’号，并保存‘-’.
    numStr = numStr.substr(1);
    sym = "-";
  }

  let regExp = new RegExp("^(((\\d+.?\\d+)|(\\d+))[Ee]{1}((-(\\d+))|(\\d+)))$", "ig");
  let result = regExp.exec(numStr);
  if (result != null) {
    resValue = result[2];
    power = result[5];
    result = null;
  }
  if (!resValue && !power) {
    return value;
  }
  let dotIndex = resValue.indexOf(".") == -1 ? 0 : resValue.indexOf(".");
  let resArr = resValue.split("");
  resValue = resValue.replace(".", "");
  let powerNum = Number(power);
  if (powerNum >= 0) {
    // 正次幂
    positivePower(powerNum, resValue, dotIndex, resArr);
  } else {
    // 负次幂
    let powerNum = Number(power.replace("-", ""));
    negativePower(powerNum, resValue, dotIndex, resArr);
  }
  resValue = resArr.join("");
  return sym + resValue;
}

// 正次幂
function positivePower(powerNum: number, resValue: string, dotIndex: number, resArr: any) {
  // 有小数
  if (dotIndex > 0) {
    let substr = resValue.substr(dotIndex);
    //幂数大于小数点后面的数字位数时，后面加0
    for (let i = 0; i < powerNum - substr.length; i++) {
      resArr.push("0");
    }
    if (powerNum - substr.length < 0) {
      resArr.splice(dotIndex + powerNum + 1, 0, ".");
    }

    if (dotIndex > 0) {
      resArr.splice(dotIndex, 1);
    }
  } else {
    for (let i = 0; i < powerNum; i++) {
      resArr.push("0");
    }
  }
}
// 负次幂
function negativePower(powerNum: number, resValue: string, dotIndex: number, resArr: any) {
  // 有小数
  if (dotIndex > 0) {
    resArr.splice(dotIndex, 1);
    //幂数大于等于 小数点的index位置, 前面加0
    for (let i = 0; i <= powerNum - dotIndex; i++) {
      resArr.unshift("0");
    }
    let n = powerNum - dotIndex >= 0 ? 1 : -(powerNum - dotIndex);
    resArr.splice(n, 0, ".");
  } else {
    for (let i = 0; i <= powerNum - resValue.length; i++) {
      resArr.unshift("0");
    }
    let n = powerNum - resValue.length >= 0 ? 1 : -(powerNum - resValue.length);
    resArr.splice(n, 0, ".");
  }
}

export {
  NumberScientificNotation
}
